@@ -228,7 +228,8 @@ class PandasMol2(object):
         return rmsd
 
     def distance(self, xyz=(0.00, 0.00, 0.00)):
-        """Computes Euclidean distance between atoms and a 3D point.
+        """Computes Euclidean distance between atoms in
+            self.df and a 3D point.
 
         Parameters
         ----------
@@ -242,18 +243,29 @@ class PandasMol2(object):
             distance between the atoms in the atom section and `xyz`.
 
         """
-        return pd.Series(np.linalg.norm(self.df[['x', 'y', 'z']]
-                                        .subtract(xyz, axis=1), axis=1))
+        return np.sqrt(np.sum(self.df[['x', 'y', 'z']]
+                       .subtract(xyz, axis=1)**2, axis=1))
 
-        # Note:
-        # The solution above is about 10% faster than
-        #
-        # return np.sqrt(np.sum(self.df[['x', 'y', 'z']]\
-        #   .subtract(xyz, axis=1)**2, axis=1))
-        #
-        # The solution below is equivalent but 300% slower:
-        #
-        # return self.df.apply(lambda x: np.sqrt(np.sum(
-        #    ((x['x'] - xyz[0])**2,
-        #     (x['y'] - xyz[1])**2,
-        #     (x['z'] - xyz[2])**2))), axis=1)
+    @staticmethod
+    def distance_df(df, xyz=(0.00, 0.00, 0.00)):
+        """Computes Euclidean distance between atoms and a 3D point.
+
+        Parameters
+        ----------
+        df : DataFrame
+            DataFrame containing entries similar to the PandasMol2.df
+            format for the
+            the distance computation to the `xyz` reference coordinates.
+        xyz : tuple (0.00, 0.00, 0.00)
+            X, Y, and Z coordinate of the reference center for the distance
+            computation
+
+        Returns
+        ---------
+        pandas.Series : Pandas Series object containing the Euclidean
+            distance between the atoms in the atom section and `xyz`.
+
+        """
+
+        return np.sqrt(np.sum(df[['x', 'y', 'z']]
+                       .subtract(xyz, axis=1)**2, axis=1))
