@@ -19,6 +19,7 @@ except ImportError:
 from .engines import pdb_records
 from .engines import pdb_df_columns
 from .engines import amino3to1dict
+import warnings
 
 
 class PandasPdb(object):
@@ -31,18 +32,18 @@ class PandasPdb(object):
         Dictionary storing pandas DataFrames for PDB record sections.
         The dictionary keys are {'ATOM', 'HETATM', 'ANISOU', 'OTHERS'}
         where 'OTHERS' contains all entries that are not parsed as
-        'ATOM', 'HETATM', or 'ANISOU'
+        'ATOM', 'HETATM', or 'ANISOU'.
 
     pdb_text : str
-        PDB file contents in raw text format
+        PDB file contents in raw text format.
 
     pdb_path : str
         Location of the PDB file that was read in via `read_pdb`
         or URL of the page where the PDB content was fetched from
-        if `fetch_pdb` was called
+        if `fetch_pdb` was called.
 
     header : str
-        PDB file description
+        PDB file description.
 
     code : str
         PDB code
@@ -75,7 +76,7 @@ class PandasPdb(object):
         Attributes
         ----------
         path : str
-            Path to the PDB file in .pdb format or gzipped format (.pdb.gz)
+            Path to the PDB file in .pdb format or gzipped format (.pdb.gz).
 
         Returns
         ---------
@@ -93,7 +94,7 @@ class PandasPdb(object):
         Parameters
         ----------
         pdb_code : str
-            A 4-letter PDB code, e.g., "3eiy"
+            A 4-letter PDB code, e.g., "3eiy".
 
         Returns
         ---------
@@ -104,21 +105,28 @@ class PandasPdb(object):
         self._df = self._construct_df(pdb_lines=self.pdb_text.splitlines(True))
         return self
 
-    def get(self, s, df=None, invert=False):
+    def get(self, s, df=None, invert=False, records=('ATOM', 'HETATM')):
         """Filter PDB DataFrames by properties
 
         Parameters
         ----------
         s : str  in {'main chain', 'hydrogen', 'c-alpha', 'heavy'}
-            String to specify which entries to return
+            String to specify which entries to return.
 
         df : pandas.DataFrame, default: None
             Optional DataFrame to perform the filter operation on.
-            If df=None, filters on self.df['ATOM']
+            If df=None, filters on self.df['ATOM'].
 
         invert : bool, default: True
             Inverts the search query. For example if s='hydrogen' and
-            invert=True, all but hydrogen entries are returned
+            invert=True, all but hydrogen entries are returned.
+
+        records : iterable, default: ('ATOM', 'HETATM')
+            Specify which record sections to consider. For example, to consider
+            both protein and ligand atoms, set `records=('ATOM', 'HETATM')`.
+            This setting is ignored if `df` is not set to None.
+            For downward compatibility, a string argument is still supported
+            but deprecated and will be removed in future versions.
 
         Returns
         --------
@@ -126,24 +134,31 @@ class PandasPdb(object):
             Returns a DataFrame view on the filtered entries.
 
         """
+        if isinstance(records, str):
+            warnings.warn('Using a string as `records` argument is '
+                          'deprecated and will not be supported in future'
+                          ' versions. Please use a tuple or'
+                          ' other iterable instead', DeprecationWarning)
+            records = (records,)
+
         if not self._get_dict:
             self._get_dict = self._init_get_dict()
         if s not in self._get_dict.keys():
             raise AttributeError('s must be in %s' % self._get_dict.keys())
         if not df:
-            df = self._df['ATOM']
+            df = pd.concat(objs=[self.df[i] for i in records])
         return self._get_dict[s](df, invert=invert)
 
-    def impute_element(self, sections=('ATOM', 'HETATM'), inplace=False):
+    def impute_element(self, records=('ATOM', 'HETATM'), inplace=False):
         """Impute element_symbol from atom_name section.
 
         Parameters
         ----------
-        sections : iterable (default: ('ATOM', 'HETATM'))
+        records : iterable, default: ('ATOM', 'HETATM')
             Coordinate sections for which the element symbols should be
             imputed.
 
-        inplace : bool (default: False)
+        inplace : bool, (default: False
             Performs the operation in-place if True and returns a copy of the
             PDB DataFrame otherwise.
 
@@ -159,7 +174,7 @@ class PandasPdb(object):
             for d in self.df:
                 t[d] = self.df[d].copy()
 
-        for sec in sections:
+        for sec in records:
             t[sec]['element_symbol'] = \
                 t[sec][['atom_name', 'element_symbol']].\
                 apply(lambda x: x[0][1]
@@ -174,11 +189,11 @@ class PandasPdb(object):
         Parameters
         ----------
         df1 : pandas.DataFrame
-            DataFrame with HETATM, ATOM, and/or ANISOU entries
+            DataFrame with HETATM, ATOM, and/or ANISOU entries.
 
         df2 : pandas.DataFrame
             Second DataFrame for RMSD computation against df1. Must have the
-            same number of entries as df1
+            same number of entries as df1.
 
         s : {'main chain', 'hydrogen', 'c-alpha', 'heavy', 'carbon'} or None,
             default: None
@@ -367,13 +382,13 @@ class PandasPdb(object):
 
         Parameters
         ----------
-        record : str (default: 'ATOM')
-            Specfies the record DataFrame
-        residue_col : str (default: 'residue_name')
+        record : str, default: 'ATOM'
+            Specfies the record DataFrame.
+        residue_col : str,  default: 'residue_name'
             Column in `record` DataFrame to look for 3-letter amino acid
-            codes for the conversion
-        fillna : str (default: '?')
-            Placeholder string to use for unknown amino acids
+            codes for the conversion.
+        fillna : str, default: '?'
+            Placeholder string to use for unknown amino acids.
 
         Returns
         ---------
@@ -397,16 +412,20 @@ class PandasPdb(object):
 
         return pd.concat((tmp.iloc[indices]['chain_id'], transl), axis=1)
 
-    def distance(self, xyz=(0.00, 0.00, 0.00), record='ATOM'):
+    def distance(self, xyz=(0.00, 0.00, 0.00), records=('ATOM', 'HETATM')):
         """Computes Euclidean distance between atoms and a 3D point.
 
         Parameters
         ----------
-        xyz : tuple (0.00, 0.00, 0.00)
+        xyz : tuple, default: (0.00, 0.00, 0.00)
             X, Y, and Z coordinate of the reference center for the distance
-            computation
-        record : str (default: 'ATOM')
-            Specfies the record DataFrame
+            computation.
+        records : iterable, default: ('ATOM', 'HETATM')
+            Specify which record sections to consider. For example, to consider
+            both protein and ligand atoms, set `records=('ATOM', 'HETATM')`.
+            This setting is ignored if `df` is not set to None.
+            For downward compatibility, a string argument is still supported
+            but deprecated and will be removed in future versions.
 
         Returns
         ---------
@@ -415,19 +434,42 @@ class PandasPdb(object):
 
         """
 
-        return pd.Series(np.linalg.norm(self.df[record][[
-            'x_coord', 'y_coord', 'z_coord']].subtract(xyz, axis=1), axis=1))
+        if isinstance(records, str):
+            warnings.warn('Using a string as `records` argument is '
+                          'deprecated and will not be supported in future'
+                          ' versions. Please use a tuple or'
+                          ' other iterable instead', DeprecationWarning)
+            records = (records,)
 
-        # Note:
-        # The solution above is about 10% faster than
-        # return np.sqrt(np.sum(self.df[record][[
-        #    'x_coord', 'y_coord', 'z_coord']]\
-        #   .subtract(xyz, axis=1)**2, axis=1))
-        # The solution below is equivalent but 300% slower:
-        # return self.df[record].apply(lambda x: np.sqrt(np.sum(
-        #    ((x['x_coord'] - xyz[0])**2,
-        #     (x['y_coord'] - xyz[1])**2,
-        #     (x['z_coord'] - xyz[2])**2))), axis=1)
+        df = pd.concat(objs=[self.df[i] for i in records])
+
+        return np.sqrt(np.sum(df[[
+            'x_coord', 'y_coord', 'z_coord']]
+            .subtract(xyz, axis=1)**2, axis=1))
+
+    @staticmethod
+    def distance_df(df, xyz=(0.00, 0.00, 0.00)):
+        """Computes Euclidean distance between atoms and a 3D point.
+
+        Parameters
+        ----------
+        df : DataFrame
+            DataFrame containing entries in the `PandasPdb.df['ATOM']`
+            or `PandasPdb.df['HETATM']` format for the
+            the distance computation to the `xyz` reference coordinates.
+        xyz : tuple, default: (0.00, 0.00, 0.00)
+            X, Y, and Z coordinate of the reference center for the distance
+            computation.
+
+        Returns
+        ---------
+        pandas.Series : Pandas Series object containing the Euclidean
+            distance between the atoms in the record section and `xyz`.
+
+        """
+        return np.sqrt(np.sum(df[[
+            'x_coord', 'y_coord', 'z_coord']]
+            .subtract(xyz, axis=1)**2, axis=1))
 
     def to_pdb(self, path, records=None, gz=False, append_newline=True):
         """Write record DataFrames to a PDB file or gzipped PDB file.
@@ -440,10 +482,10 @@ class PandasPdb(object):
         records : iterable, default: None
             A list of PDB record sections in
             {'ATOM', 'HETATM', 'ANISOU', 'OTHERS'} that are to be written.
-            Writes all lines to PDB if records=None
+            Writes all lines to PDB if `records=None`.
 
         gz : bool, default: False
-            Writes a gzipped PDB file if True
+            Writes a gzipped PDB file if True.
 
         append_newline : bool, default: True
             Appends a new line at the end of the PDB file if True
@@ -497,3 +539,6 @@ class PandasPdb(object):
                     f.write('\n')
                 else:
                     f.write('\n')
+
+    def parse_sse(self):
+        """Parse secondary structure elements"""
